/*
 * Copyright 2015 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.common.protocol;


/**
 * <p>
 * Base class for <code>CA_PROTO_WRITE_NOTIFY</code> messages.
 * </p>
 * 
 * <p>
 * This message type is used by clients to write to a channel and by servers to
 * reply to such a write request. In contrast, the
 * {@link ChannelAccessCommand#CA_PROTO_WRITE} message is used by a client to
 * write to a channel without getting a reply from the server.
 * </p>
 * 
 * @see ChannelAccessCommand#CA_PROTO_WRITE_NOTIFY
 * @see ChannelAccessWriteNotifyClientMessage
 * @see ChannelAccessWriteNotifyServerMessage
 * 
 * @author Sebastian Marsching
 */
public abstract class ChannelAccessWriteNotifyMessage extends
        ChannelAccessMessage {

    /**
     * Constructor. This constructor only sets the message command to
     * {@link ChannelAccessCommand#CA_PROTO_WRITE_NOTIFY}. All other fields
     * depend on the context in which the message is sent. This constructor is
     * package-private, so that only classes in this package can inherit from
     * this class.
     */
    ChannelAccessWriteNotifyMessage() {
        super(ChannelAccessCommand.CA_PROTO_WRITE_NOTIFY);
    }

    /**
     * Constructor. This constructor sets the message command to
     * {@link ChannelAccessCommand#CA_PROTO_READ_NOTIFY} and stores the message
     * header that is used to construct this message. All other fields depend on
     * the context in which the message is sent. This constructor is
     * package-private, so that only classes in this package can inherit from
     * this class.
     * 
     * @param messageHeader
     *            the message header that is used to for creating this message.
     *            This header is passed on to the
     *            {@link ChannelAccessMessage#ChannelAccessMessage(ChannelAccessCommand, ChannelAccessMessageHeader)}
     *            constructor.
     */
    ChannelAccessWriteNotifyMessage(ChannelAccessMessageHeader messageHeader) {
        super(ChannelAccessCommand.CA_PROTO_WRITE_NOTIFY, messageHeader);
    }

}
