/*
 * Copyright 2016-2019 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.common.util;

import java.io.IOException;
import java.net.StandardProtocolFamily;
import java.net.StandardSocketOptions;
import java.nio.channels.ClosedChannelException;
import java.nio.channels.DatagramChannel;

/**
 * <p>
 * Utility methods for dealing with {@link DatagramChannel}s.
 * </p>
 * 
 * <p>
 * In the past, the methods provided by this class were used to provide access
 * to functionality only available in Java 7 without breaking compatibility with
 * Java 6. As EPICS Jackie depends on Java 8 since version 3.0.0 this class is
 * deprecated now and is going to be removed in a future release.
 * </p>
 * 
 * @author Sebastian Marsching
 * @deprecated since EPICS Jackie 3.0.0.
 */
public final class DatagramChannelUtil {

    private DatagramChannelUtil() {
    }

    /**
     * <p>
     * Opens a new {@link DatagramChannel} that is limited to IPV4. Calling this
     * method is equivalent to calling
     * <code>DatagramChannel.open(StandardProtocolFamily.INET)</code>.
     * </p>
     * 
     * <p>
     * This method is only provided for backwards compatibility with older
     * versions of EPICS Jackie and should not be used any longer.
     * </p>
     * 
     * @return datagram channel returned by
     *         <code>DatagramChannel.open(StandardProtocolFamily.INET)</code>.
     * @throws IOException
     *             if the called <code>open</code> method throws such an
     *             exception.
     * @deprecated since EPICS Jackie 3.0.0. Directly use the Java 7 SE API
     *             instead.
     */
    public static DatagramChannel openChannelInet4() throws IOException {
        return DatagramChannel.open(StandardProtocolFamily.INET);
    }

    /**
     * <p>
     * Sets the IP multicast loop option on a datagram channel. Calling this
     * method is equivalent to calling
     * <code>channel.setOption(StandardSocketOptions.IP_MULTICAST_LOOP, loopBack)</code>.
     * </p>
     * 
     * <p>
     * This method is only provided for backwards compatibility with older
     * versions of EPICS Jackie and should not be used any longer.
     * </p>
     * 
     * @param channel
     *            channel on which the <code>setOption</code> method should be
     *            called.
     * @param loopBack
     *            new value for the <code>IP_MULTICAST_LOOP</code> flag.
     * @throws ClosedChannelException
     *             if <code>setOption</code> throws such an exception.
     * @throws IllegalArgumentException
     *             if <code>setOption</code> throws such an exception.
     * @throws IOException
     *             if <code>setOption</code> throws such an exception.
     * @throws UnsupportedOperationException
     *             if <code>setOption</code> throws such an exception.
     * @deprecated since EPICS Jackie 3.0.0. Directly use the Java 7 SE API
     *             instead.
     */
    public static void setIpMulticastLoopOption(DatagramChannel channel,
            boolean loopBack) throws IOException {
        channel.setOption(StandardSocketOptions.IP_MULTICAST_LOOP, loopBack);
    }

    /**
     * <p>
     * Sets the IP multicast ttl option on a datagram channel. Calling this
     * method is equivalent to calling
     * <code>channel.setOption(StandardSocketOptions.IP_MULTICAST_TTL, ttl)</code>.
     * </p>
     * 
     * <p>
     * This method is only provided for backwards compatibility with older
     * versions of EPICS Jackie and should not be used any longer.
     * </p>
     * 
     * @param channel
     *            channel on which the <code>setOption</code> method should be
     *            called.
     * @param ttl
     *            new value for the <code>IP_MULTICAST_TTL</code> option.
     * @throws ClosedChannelException
     *             if <code>setOption</code> throws such an exception.
     * @throws IllegalArgumentException
     *             if <code>setOption</code> throws such an exception.
     * @throws IOException
     *             if <code>setOption</code> throws such an exception.
     * @throws UnsupportedOperationException
     *             if <code>setOption</code> throws such an exception.
     * @deprecated since EPICS Jackie 3.0.0. Directly use the Java 7 SE API
     *             instead.
     */
    public static void setIpMulticastTtlOption(DatagramChannel channel, int ttl)
            throws IOException {
        channel.setOption(StandardSocketOptions.IP_MULTICAST_TTL, ttl);
    }

}
